@@ -4,7 +4,7 @@
     <message>
         <source/>
         <translatorcomment>Bibletime User Interface translation
-Copyright (C) 1999-2015 The Bibletime Team, http://www.bibletime.info
+Copyright (C) 1999-2016 The Bibletime Team, http://www.bibletime.info
 This file is distributed under the same license as the Bibetime package.</translatorcomment>
         <translation type="unfinished"/>
     </message>
@@ -42,6 +42,142 @@ This file is distributed under the same license as the Bibetime package.</transl
         <translation>Lizensier unter der</translation>
     </message>
 </context>
+<context>
+    <name>AddBookmark</name>
+    <message>
+        <location filename="../../src/mobile/qml/AddBookmark.qml" line="113"/>
+        <source>Choose</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddBookmark.qml" line="165"/>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddBookmark.qml" line="186"/>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+</context>
+<context>
+    <name>AddFolder</name>
+    <message>
+        <location filename="../../src/mobile/qml/AddFolder.qml" line="176"/>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddFolder.qml" line="197"/>
+        <source>Cancel</source>
+        <translation>Abbrechen</translation>
+    </message>
+</context>
+<context>
+    <name>BookmarkFolders</name>
+    <message>
+        <location filename="../../src/mobile/qml/BookmarkFolders.qml" line="179"/>
+        <source>New Folder</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>BookmarkManager</name>
+    <message>
+        <location filename="../../src/mobile/qml/BookmarkManager.qml" line="244"/>
+        <source>New Folder</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>Bookmarks</name>
+    <message>
+        <location filename="../../src/mobile/qml/AddBookmark.qml" line="62"/>
+        <source>Add Bookmark</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddBookmark.qml" line="78"/>
+        <source>Bookmark</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddBookmark.qml" line="106"/>
+        <source>Folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddFolder.qml" line="59"/>
+        <source>New Folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddFolder.qml" line="69"/>
+        <source>Folder Name</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/AddFolder.qml" line="126"/>
+        <source>Parent folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/BookmarkFolders.qml" line="82"/>
+        <source>Choose Folder</source>
+        <translation>Ordner auswählen</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/BookmarkManager.qml" line="106"/>
+        <source>Bookmark Manager</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>Copy</name>
+    <message>
+        <location filename="../../src/mobile/qml/CopyVerses.qml" line="193"/>
+        <source>Copy</source>
+        <translation>Kopieren</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/CopyVerses.qml" line="234"/>
+        <source>Copy size to large.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>Default Documents</name>
+    <message>
+        <location filename="../../src/mobile/qml/DefaultDoc.qml" line="65"/>
+        <source>Standard Documents</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/DefaultDoc.qml" line="83"/>
+        <source>Bible:</source>
+        <translation>Bibel</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/DefaultDoc.qml" line="130"/>
+        <source>Hebrew Strong&apos;s lexicon:</source>
+        <translation>Hebräisches Strong&apos;s Lexikon:</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/DefaultDoc.qml" line="176"/>
+        <source>Greek Strong&apos;s lexicon:</source>
+        <translation>Griechisches Strong&apos;s Lexikon:</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/DefaultDoc.qml" line="221"/>
+        <source>Hebrew Morphological lexicon:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/DefaultDoc.qml" line="267"/>
+        <source>Greek Morphological lexicon:</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>FontSizeSlider</name>
     <message>
@@ -55,6 +191,14 @@ This file is distributed under the same license as the Bibetime package.</transl
         <translation>Abbrechen</translation>
     </message>
 </context>
+<context>
+    <name>InformationDialog</name>
+    <message>
+        <location filename="../../src/mobile/qml/InformationDialog.qml" line="53"/>
+        <source>Close</source>
+        <translation>Schließen</translation>
+    </message>
+</context>
 <context>
     <name>Install Documents</name>
     <message>
@@ -71,36 +215,44 @@ This file is distributed under the same license as the Bibetime package.</transl
 <context>
     <name>InstallManagerChooser</name>
     <message>
-        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="73"/>
+        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="103"/>
         <source>Source</source>
         <translation>Quelle</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="81"/>
+        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="125"/>
         <source>Category</source>
         <translation>Kategorie</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="92"/>
+        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="146"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="104"/>
+        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="165"/>
         <source>Document</source>
         <translation>Dokument</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="134"/>
+        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="195"/>
         <source>Refresh Sources</source>
         <translation>Quellen aktualisieren</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="151"/>
+        <location filename="../../src/mobile/qml/InstallManagerChooser.qml" line="215"/>
         <source>Install / Remove</source>
         <translation>Installieren / Entfernen</translation>
     </message>
 </context>
+<context>
+    <name>MagView</name>
+    <message>
+        <location filename="../../src/mobile/qml/MagView.qml" line="100"/>
+        <source>View References</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolbar</name>
     <message>
@@ -112,22 +264,22 @@ This file is distributed under the same license as the Bibetime package.</transl
 <context>
     <name>ModuleChooser</name>
     <message>
-        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="121"/>
+        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="123"/>
         <source>Unlock</source>
         <translation>Freischalten</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="170"/>
+        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="180"/>
         <source>Category</source>
         <translation>Kategorie</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="181"/>
+        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="192"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="193"/>
+        <location filename="../../src/mobile/qml/ModuleChooser.qml" line="205"/>
         <source>Work</source>
         <translation>Werk</translation>
     </message>
@@ -156,7 +308,7 @@ This file is distributed under the same license as the Bibetime package.</transl
 <context>
     <name>Quit</name>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="495"/>
+        <location filename="../../src/mobile/qml/main.qml" line="533"/>
         <source>Are you sure you want to quit?</source>
         <translation>Sind Sie sicher, dass Sie das Programm verlassen möchtenß</translation>
     </message>
@@ -164,33 +316,33 @@ This file is distributed under the same license as the Bibetime package.</transl
 <context>
     <name>Search</name>
     <message>
-        <location filename="../../src/mobile/qml/Search.qml" line="71"/>
-        <location filename="../../src/mobile/qml/Search.qml" line="119"/>
+        <location filename="../../src/mobile/qml/Search.qml" line="70"/>
+        <location filename="../../src/mobile/qml/Search.qml" line="118"/>
         <source>Search</source>
         <translation>Suche</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/Search.qml" line="147"/>
+        <location filename="../../src/mobile/qml/Search.qml" line="146"/>
         <source>Find</source>
         <translation>Finden</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/Search.qml" line="165"/>
+        <location filename="../../src/mobile/qml/Search.qml" line="164"/>
         <source>All Words</source>
         <translation>Alle Wörter</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/Search.qml" line="181"/>
+        <location filename="../../src/mobile/qml/Search.qml" line="180"/>
         <source>Any Word</source>
         <translation>Irgendein Wort</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/Search.qml" line="196"/>
+        <location filename="../../src/mobile/qml/Search.qml" line="195"/>
         <source>Regular Expression</source>
         <translation>Regulärer Ausdruck</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/Search.qml" line="222"/>
+        <location filename="../../src/mobile/qml/Search.qml" line="221"/>
         <source>Search in</source>
         <translation>Suche in</translation>
     </message>
@@ -198,12 +350,12 @@ This file is distributed under the same license as the Bibetime package.</transl
 <context>
     <name>SearchResults</name>
     <message>
-        <location filename="../../src/mobile/qml/SearchResults.qml" line="127"/>
+        <location filename="../../src/mobile/qml/SearchResults.qml" line="160"/>
         <source>Documents</source>
         <translation>Dokumente</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/SearchResults.qml" line="158"/>
+        <location filename="../../src/mobile/qml/SearchResults.qml" line="191"/>
         <source>References</source>
         <translation>Referenzen</translation>
     </message>
@@ -254,33 +406,143 @@ This file is distributed under the same license as the Bibetime package.</transl
         <translation>Abbrechen</translation>
     </message>
 </context>
+<context>
+    <name>TextEditor</name>
+    <message>
+        <location filename="../../src/mobile/qml/TextEditor.qml" line="50"/>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+</context>
+<context>
+    <name>VerseChooser</name>
+    <message>
+        <location filename="../../src/mobile/qml/VerseChooser.qml" line="35"/>
+        <source>Book</source>
+        <translation>Buch</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/VerseChooser.qml" line="45"/>
+        <source>Chapter</source>
+        <translation>Kapitel</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/VerseChooser.qml" line="53"/>
+        <source>Verse</source>
+        <translation>Vers</translation>
+    </message>
+</context>
 <context>
     <name>Welcome</name>
     <message>
-        <location filename="../../src/mobile/qml/WindowManager.qml" line="265"/>
+        <location filename="../../src/mobile/qml/WindowManager.qml" line="301"/>
         <source>Use the &quot;New Window&quot; menu to open a document.</source>
         <translation>Verwenden Sie das Menü &quot;Neues Fenster&quot;, um ein Dokument zu öffnen.</translation>
     </message>
 </context>
 <context>
-    <name>btm::BtSearchInterface</name>
+    <name>Window</name>
     <message>
-        <location filename="../../src/mobile/ui/btsearchinterface.cpp" line="58"/>
-        <source>Indexing</source>
-        <translation>Indexierung</translation>
+        <location filename="../../src/mobile/qml/Window.qml" line="83"/>
+        <source>Add BookMark</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/Window.qml" line="84"/>
+        <source>Bookmarks</source>
+        <translation>Lesezeichen</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/Window.qml" line="87"/>
+        <source>Copy</source>
+        <translation>Kopieren</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/Window.qml" line="90"/>
+        <source>View References</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/Window.qml" line="92"/>
+        <source>Add Parallel Document</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/Window.qml" line="94"/>
+        <source>Remove Parallel Document</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/Window.qml" line="96"/>
+        <source>Close Window</source>
+        <translation>Fenster schließen</translation>
     </message>
 </context>
 <context>
-    <name>btm::InstallProgress</name>
+    <name>btm::BtBookmarkInterface</name>
     <message>
-        <location filename="../../src/mobile/bookshelfmanager/installprogress.cpp" line="96"/>
-        <source>Installing</source>
-        <translation>Installation</translation>
+        <location filename="../../src/mobile/ui/btbookmarkinterface.cpp" line="87"/>
+        <source>Bookmarks</source>
+        <translation>Lesezeichen</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/bookshelfmanager/installprogress.cpp" line="102"/>
-        <source>Downloading</source>
-        <translation>Herunterladen</translation>
+        <location filename="../../src/mobile/ui/btbookmarkinterface.cpp" line="189"/>
+        <source>Expand/Collapse</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/ui/btbookmarkinterface.cpp" line="192"/>
+        <source>Open</source>
+        <translation>Öffnen</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/ui/btbookmarkinterface.cpp" line="195"/>
+        <source>Delete folder and bookmarks</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/ui/btbookmarkinterface.cpp" line="197"/>
+        <source>Delete bookmark</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>btm::BtSearchInterface</name>
+    <message>
+        <location filename="../../src/mobile/ui/btsearchinterface.cpp" line="60"/>
+        <source>Indexing %1</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>btm::BtWindowInterface</name>
+    <message>
+        <location filename="../../src/mobile/ui/btwindowinterface.cpp" line="57"/>
+        <source>Select a reference.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/ui/btwindowinterface.cpp" line="229"/>
+        <source>Footnote</source>
+        <translation>Fußnote</translation>
+    </message>
+</context>
+<context>
+    <name>btm::InstallInterface</name>
+    <message>
+        <location filename="../../src/mobile/ui/installinterface.cpp" line="282"/>
+        <source>Refreshing Source List</source>
+        <translation>Aktualisiere Quellenliste</translation>
+    </message>
+    <message>
+        <location filename="../../src/mobile/ui/installinterface.cpp" line="373"/>
+        <source>Installing %1</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/ui/installinterface.cpp" line="378"/>
+        <source>Downloading %1</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -297,126 +559,164 @@ This file is distributed under the same license as the Bibetime package.</transl
     </message>
 </context>
 <context>
-    <name>btm::InstallSourcesManager</name>
+    <name>copy</name>
     <message>
-        <location filename="../../src/mobile/bookshelfmanager/installsourcesmanager.cpp" line="45"/>
-        <source>Refreshing Source List</source>
-        <translation>Aktualisiere Quellenliste</translation>
-    </message>
-</context>
-<context>
-    <name>btm::VerseChooser</name>
-    <message>
-        <location filename="../../src/mobile/keychooser/versechooser.cpp" line="52"/>
-        <source>Book</source>
-        <translation>Buch</translation>
+        <location filename="../../src/mobile/qml/CopyVerses.qml" line="125"/>
+        <source>Document</source>
+        <translation>Dokument</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/keychooser/versechooser.cpp" line="61"/>
-        <source>Chapter</source>
-        <translation>Kapitel</translation>
+        <location filename="../../src/mobile/qml/CopyVerses.qml" line="146"/>
+        <source>First</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../../src/mobile/keychooser/versechooser.cpp" line="68"/>
-        <source>Verse</source>
-        <translation>Vers</translation>
+        <location filename="../../src/mobile/qml/CopyVerses.qml" line="169"/>
+        <source>Last</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="233"/>
+        <location filename="../../src/mobile/qml/main.qml" line="318"/>
         <source>Some of the modules you want to search need to be indexed. Do you want to index them now?</source>
         <translation>Einige Module müssen für die Suche indexiert werden. Wollen Sie diese jetzt indexieren?</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="321"/>
+        <location filename="../../src/mobile/qml/main.qml" line="465"/>
+        <location filename="../../src/mobile/qml/main.qml" line="792"/>
         <source>New Window</source>
         <translation>Neues Fenster</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="322"/>
+        <location filename="../../src/mobile/qml/main.qml" line="466"/>
         <source>View Window</source>
         <translation>Anzeigefenster</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="323"/>
-        <source>Close Window</source>
-        <translation>Fenster schließen</translation>
-    </message>
-    <message>
-        <location filename="../../src/mobile/qml/main.qml" line="326"/>
-        <location filename="../../src/mobile/qml/main.qml" line="476"/>
+        <location filename="../../src/mobile/qml/main.qml" line="850"/>
+        <location filename="../../src/mobile/qml/main.qml" line="898"/>
         <source>User Interface Font Size</source>
         <translation>Programm-Schriftgröße</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="327"/>
+        <location filename="../../src/mobile/qml/main.qml" line="851"/>
         <source>Window Arrangement</source>
         <translation>Fenster-Anordnung</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="324"/>
+        <location filename="../../src/mobile/qml/main.qml" line="467"/>
         <source>Manage Installed Documents</source>
         <translation>Installierte Dokumente verwalten</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="329"/>
+        <location filename="../../src/mobile/qml/main.qml" line="468"/>
+        <source>Settings</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="470"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="418"/>
+        <location filename="../../src/mobile/qml/main.qml" line="272"/>
         <source>Dark</source>
         <translation>Dunkel</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="419"/>
+        <location filename="../../src/mobile/qml/main.qml" line="273"/>
         <source>Light Blue</source>
         <translation>Hellblau</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="420"/>
+        <location filename="../../src/mobile/qml/main.qml" line="274"/>
         <source>Crimson</source>
         <translation>Purpur</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="381"/>
+        <location filename="../../src/mobile/qml/main.qml" line="853"/>
+        <source>Default Documents</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="980"/>
         <source>Single</source>
         <translation>Einzel</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="178"/>
+        <location filename="../../src/mobile/qml/main.qml" line="423"/>
         <source>BibleTime views documents such as Bibles and commentaries. These documents are downloaded and stored locally.There are currently no documents. Do you want to install documents now?</source>
         <translation>BibleTime zeigt Dokumente wie Bibeln und Kommentare an. Diese Dokumente werden heruntergeladen und lokal gespeichert. Derzeit sind keine Dokumente vorhanden. Möchten Sie jetzt Dokumente installieren?</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="325"/>
+        <location filename="../../src/mobile/qml/main.qml" line="376"/>
+        <source>New Feature</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="378"/>
+        <source>You can write your own comments about Bible verses.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="379"/>
+        <source>Install the Personal commentary from Crosswire.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="380"/>
+        <source>Then open the Personal commentary and select a verse.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="381"/>
+        <source>You can then enter your text.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="383"/>
+        <source>The Personal Commentary can be one of your Parallel Documents.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="469"/>
+        <source>New Features</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="793"/>
+        <source>View References</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../../src/mobile/qml/main.qml" line="849"/>
         <source>Text Font</source>
         <translation>Schriftart für Text</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="328"/>
+        <location filename="../../src/mobile/qml/main.qml" line="852"/>
         <source>Color Theme</source>
         <translation>Farbschema</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="382"/>
+        <location filename="../../src/mobile/qml/main.qml" line="981"/>
         <source>Tabbed</source>
         <translation>Tabs</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="383"/>
+        <location filename="../../src/mobile/qml/main.qml" line="982"/>
         <source>Auto-tile</source>
         <translation>Automatisch Kacheln</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="384"/>
+        <location filename="../../src/mobile/qml/main.qml" line="983"/>
         <source>Auto-tile horizontally</source>
         <translation>Automatisch horizontal kacheln</translation>
     </message>
     <message>
-        <location filename="../../src/mobile/qml/main.qml" line="385"/>
+        <location filename="../../src/mobile/qml/main.qml" line="984"/>
         <source>Auto-tile vertically</source>
         <translation>Autmatisch vertikal kacheln</translation>
     </message>
