@@ -4,27 +4,30 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "backend/bookshelfmodel/btbookshelftreemodel.h"
+#include "btbookshelftreemodel.h"
 
-#include <QSet>
-#include "backend/bookshelfmodel/categoryitem.h"
-#include "backend/bookshelfmodel/indexingitem.h"
-#include "backend/bookshelfmodel/languageitem.h"
-#include "backend/bookshelfmodel/moduleitem.h"
-#include "backend/config/btconfig.h"
-#include "util/macros.h"
+#include <type_traits>
+#include "../../util/btassert.h"
+#include "../../util/btconnect.h"
+#include "../../util/macros.h"
+#include "../config/btconfig.h"
+#include "categoryitem.h"
+#include "indexingitem.h"
+#include "languageitem.h"
+#include "moduleitem.h"
 
+#include <QDebug>
 
 using namespace BookshelfModel;
 
 bool BtBookshelfTreeModel::Grouping::loadFrom(const QString & configKey) {
-    Q_ASSERT(!configKey.isNull());
+    BT_ASSERT(!configKey.isNull());
     QVariant v = btConfig().qVariantValue(configKey, QVariant());
     if (!v.canConvert<Grouping>())
         return false;
@@ -34,13 +37,13 @@ bool BtBookshelfTreeModel::Grouping::loadFrom(const QString & configKey) {
 }
 
 void BtBookshelfTreeModel::Grouping::saveTo(const QString & configKey) const {
-    Q_ASSERT(!configKey.isNull());
+    BT_ASSERT(!configKey.isNull());
     btConfig().setValue(configKey, QVariant::fromValue(*this));
 }
 
 BtBookshelfTreeModel::BtBookshelfTreeModel(QObject * parent)
     : QAbstractItemModel(parent)
-    , m_sourceModel(0)
+    , m_sourceModel(nullptr)
     , m_rootItem(new RootItem)
     , m_defaultChecked(MODULE_HIDDEN)
     , m_checkable(false) {}
@@ -48,7 +51,7 @@ BtBookshelfTreeModel::BtBookshelfTreeModel(QObject * parent)
 BtBookshelfTreeModel::BtBookshelfTreeModel(const QString & configKey,
                                            QObject * parent)
        : QAbstractItemModel(parent)
-       , m_sourceModel(0)
+       , m_sourceModel(nullptr)
        , m_rootItem(new RootItem)
        , m_groupingOrder(configKey)
        , m_defaultChecked(MODULE_HIDDEN)
@@ -57,7 +60,7 @@ BtBookshelfTreeModel::BtBookshelfTreeModel(const QString & configKey,
 BtBookshelfTreeModel::BtBookshelfTreeModel(const Grouping & grouping,
                                            QObject * parent)
         : QAbstractItemModel(parent)
-        , m_sourceModel(0)
+        , m_sourceModel(nullptr)
         , m_rootItem(new RootItem)
         , m_groupingOrder(grouping)
         , m_defaultChecked(MODULE_HIDDEN)
@@ -99,9 +102,9 @@ QModelIndex BtBookshelfTreeModel::parent(const QModelIndex & index) const {
         return QModelIndex();
 
     Item * childItem(static_cast<Item*>(index.internalPointer()));
-    Q_ASSERT(childItem != 0);
+    BT_ASSERT(childItem);
     Item * parentItem(childItem->parent());
-    Q_ASSERT(parentItem != 0);
+    BT_ASSERT(parentItem);
 
     if (parentItem == m_rootItem)
         return QModelIndex();
@@ -114,7 +117,7 @@ QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
         return QVariant();
 
     const Item * const i = static_cast<Item*>(index.internalPointer());
-    Q_ASSERT(i != 0);
+    BT_ASSERT(i);
     switch (role) {
 
         case Qt::CheckStateRole:
@@ -146,15 +149,15 @@ QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
 }
 
 QVariant BtBookshelfTreeModel::data(CSwordModuleInfo & module, int role) const {
-    Q_ASSERT(m_sourceIndexMap.contains(&module));
+    BT_ASSERT(m_sourceIndexMap.contains(&module));
     return m_sourceModel->data(m_sourceIndexMap.value(&module), role);
 }
 
 bool BtBookshelfTreeModel::setData(const QModelIndex & itemIndex,
                                    const QVariant & value,
                                    int role) {
-    Q_ASSERT(itemIndex.isValid());
-    typedef QPair<Item *, QModelIndex> IP;
+    BT_ASSERT(itemIndex.isValid());
+    using IP = QPair<Item *, QModelIndex>;
 
     if (UNLIKELY(role != Qt::CheckStateRole))
         return false;
@@ -169,7 +172,7 @@ bool BtBookshelfTreeModel::setData(const QModelIndex & itemIndex,
         newState = Qt::Checked;
 
     Item * item = static_cast<Item *>(itemIndex.internalPointer());
-    Q_ASSERT(item != 0);
+    BT_ASSERT(item);
     if (item->checkState() == newState) return false;
 
     // Recursively (un)check all children:
@@ -209,7 +212,7 @@ bool BtBookshelfTreeModel::setData(const QModelIndex & itemIndex,
 
 Qt::ItemFlags BtBookshelfTreeModel::flags(const QModelIndex & index) const {
     if (!index.isValid())
-        return 0;
+        return nullptr;
 
     Qt::ItemFlags f(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 
@@ -238,10 +241,13 @@ void BtBookshelfTreeModel::setSourceModel(QAbstractItemModel * sourceModel) {
     if (m_sourceModel == sourceModel)
         return;
 
-    if (m_sourceModel != 0) {
-        disconnect(this, SLOT(moduleInserted(QModelIndex, int, int)));
-        disconnect(this, SLOT(moduleRemoved(QModelIndex, int, int)));
-        disconnect(this, SLOT(moduleDataChanged(QModelIndex, QModelIndex)));
+    if (m_sourceModel != nullptr) {
+        disconnect(m_sourceModel, &QAbstractItemModel::rowsAboutToBeRemoved,
+                   this,          &BtBookshelfTreeModel::moduleRemoved);
+        disconnect(m_sourceModel, &QAbstractItemModel::rowsInserted,
+                   this,          &BtBookshelfTreeModel::moduleInserted);
+        disconnect(m_sourceModel, &QAbstractItemModel::dataChanged,
+                   this,          &BtBookshelfTreeModel::moduleDataChanged);
         beginRemoveRows(QModelIndex(), 0, m_rootItem->children().size() - 1);
         delete m_rootItem;
         m_modules.clear();
@@ -253,13 +259,13 @@ void BtBookshelfTreeModel::setSourceModel(QAbstractItemModel * sourceModel) {
 
     m_sourceModel = sourceModel;
 
-    if (sourceModel != 0) {
-        connect(sourceModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)),
-                this,        SLOT(moduleRemoved(QModelIndex, int, int)));
-        connect(sourceModel, SIGNAL(rowsInserted(QModelIndex, int, int)),
-                this,        SLOT(moduleInserted(QModelIndex, int, int)));
-        connect(sourceModel, SIGNAL(dataChanged(QModelIndex, QModelIndex)),
-                this,        SLOT(moduleDataChanged(QModelIndex, QModelIndex)));
+    if (sourceModel != nullptr) {
+        BT_CONNECT(sourceModel, &QAbstractItemModel::rowsAboutToBeRemoved,
+                   this,        &BtBookshelfTreeModel::moduleRemoved);
+        BT_CONNECT(sourceModel, &QAbstractItemModel::rowsInserted,
+                   this,        &BtBookshelfTreeModel::moduleInserted);
+        BT_CONNECT(sourceModel, &QAbstractItemModel::dataChanged,
+                   this,        &BtBookshelfTreeModel::moduleDataChanged);
 
         for (int i = 0; i < sourceModel->rowCount(); i++) {
             const QModelIndex moduleIndex(sourceModel->index(i, 0));
@@ -291,8 +297,8 @@ void BtBookshelfTreeModel::setGroupingOrder(const Grouping & groupingOrder,
 
     m_groupingOrder = groupingOrder;
 
-    if (m_sourceModel != 0) {
-        const QSet<CSwordModuleInfo *> checked(m_checkedModulesCache);
+    if (m_sourceModel != nullptr) {
+        BtModuleSet const checked(m_checkedModulesCache);
         m_checkedModulesCache.clear();
 
         beginRemoveRows(QModelIndex(), 0, m_rootItem->children().size() - 1);
@@ -319,15 +325,15 @@ void BtBookshelfTreeModel::setCheckable(bool checkable) {
     if (m_checkable == checkable)
         return;
     m_checkable = checkable;
-    if (m_sourceModel == 0)
+    if (m_sourceModel == nullptr)
         return;
 
     // Notify views that flags changed for all items:
     resetData();
 }
 
-void BtBookshelfTreeModel::setCheckedModules(const QSet<CSwordModuleInfo *> & modules) {
-    typedef ModuleItemMap::const_iterator MIMCI;
+void BtBookshelfTreeModel::setCheckedModules(BtConstModuleSet const & modules) {
+    using MIMCI = ModuleItemMap::const_iterator;
 
     for (MIMCI it = m_modules.constBegin(); it != m_modules.constEnd(); ++it) {
         if (modules.contains(it.key())) {
@@ -357,9 +363,7 @@ void BtBookshelfTreeModel::addModule(CSwordModuleInfo & module, bool checked) {
     if (m_modules.contains(&module))
         return;
 
-#if QT_VERSION >= 0x040600
     beginResetModel();
-#endif
     Grouping g(m_groupingOrder);
     addModule(module, QModelIndex(), g, checked);
 
@@ -370,11 +374,7 @@ void BtBookshelfTreeModel::addModule(CSwordModuleInfo & module, bool checked) {
            themselves.
     */
 
-#if QT_VERSION >= 0x040600
     endResetModel();
-#else
-    reset();
-#endif
 }
 
 void BtBookshelfTreeModel::addModule(CSwordModuleInfo & module,
@@ -422,7 +422,7 @@ void BtBookshelfTreeModel::addModule(CSwordModuleInfo & module,
 }
 
 void BtBookshelfTreeModel::removeModule(CSwordModuleInfo & module) {
-    typedef ModuleItemMap::iterator MIMI;
+    using MIMI = ModuleItemMap::iterator;
     const MIMI it = m_modules.find(&module);
     if (it == m_modules.end())
         return;
@@ -430,11 +430,11 @@ void BtBookshelfTreeModel::removeModule(CSwordModuleInfo & module) {
     Item * i = it.value();
 
     // Set i to be the lowest item (including empty groups) to remove:
-    Q_ASSERT(i->parent());
+    BT_ASSERT(i->parent());
     while (i->parent() != m_rootItem && i->parent()->children().size() <= 1)
         i = i->parent();
-    Q_ASSERT(i);
-    Q_ASSERT(i->parent());
+    BT_ASSERT(i);
+    BT_ASSERT(i->parent());
 
     // Calculate item indexes:
     const int index = i->childIndex();
@@ -456,7 +456,7 @@ Item & BtBookshelfTreeModel::getItem(const QModelIndex & index) const {
         return *m_rootItem;
 
     Item * const item = static_cast<Item *>(index.internalPointer());
-    Q_ASSERT(item);
+    BT_ASSERT(item);
     return *item;
 }
 
@@ -495,7 +495,7 @@ void BtBookshelfTreeModel::resetParentCheckStates(QModelIndex parentIndex) {
                 if (haveUncheckedChildren)
                     break;
             } else {
-                Q_ASSERT(state == Qt::Unchecked);
+                BT_ASSERT(state == Qt::Unchecked);
                 haveUncheckedChildren = true;
                 if (haveCheckedChildren)
                     break;
@@ -523,10 +523,10 @@ void BtBookshelfTreeModel::resetParentCheckStates(QModelIndex parentIndex) {
 void BtBookshelfTreeModel::moduleDataChanged(const QModelIndex & topLeft,
                                              const QModelIndex & bottomRight)
 {
-    Q_ASSERT(!topLeft.parent().isValid());
-    Q_ASSERT(!bottomRight.parent().isValid());
-    Q_ASSERT(topLeft.column() == 0);
-    Q_ASSERT(bottomRight.column() == 0);
+    BT_ASSERT(!topLeft.parent().isValid());
+    BT_ASSERT(!bottomRight.parent().isValid());
+    BT_ASSERT(topLeft.column() == 0);
+    BT_ASSERT(bottomRight.column() == 0);
 
     for (int i = topLeft.row(); i <= bottomRight.row(); i++) {
         const QModelIndex moduleIndex(m_sourceModel->index(i, 0, topLeft.parent()));
@@ -534,7 +534,7 @@ void BtBookshelfTreeModel::moduleDataChanged(const QModelIndex & topLeft,
                                                 BtBookshelfModel::ModulePointerRole));
         CSwordModuleInfo & module = *static_cast<CSwordModuleInfo *>(data.value<void *>());
         QModelIndex itemIndex(getIndex(*m_modules[&module]));
-        Q_ASSERT(itemIndex.isValid());
+        BT_ASSERT(itemIndex.isValid());
 
         emit dataChanged(itemIndex, itemIndex);
 
@@ -553,7 +553,7 @@ void BtBookshelfTreeModel::moduleInserted(const QModelIndex & parent,
                                           int start,
                                           int end)
 {
-    Q_ASSERT(start <= end);
+    BT_ASSERT(start <= end);
 
     for (int i = start; i <= end; i++) {
         const QModelIndex moduleIndex(m_sourceModel->index(i, 0, parent));
@@ -569,7 +569,7 @@ void BtBookshelfTreeModel::moduleInserted(const QModelIndex & parent,
             checked = !m_sourceModel->data(moduleIndex,
                                            BtBookshelfModel::ModuleHasIndexRole).toBool();
         } else {
-            Q_ASSERT(m_defaultChecked == CHECKED || m_defaultChecked == UNCHECKED);
+            BT_ASSERT(m_defaultChecked == CHECKED || m_defaultChecked == UNCHECKED);
             checked = (m_defaultChecked == CHECKED);
         }
         m_sourceIndexMap[&module] = moduleIndex;
@@ -581,7 +581,7 @@ void BtBookshelfTreeModel::moduleRemoved(const QModelIndex & parent,
                                          int start,
                                          int end)
 {
-    Q_ASSERT(start <= end);
+    BT_ASSERT(start <= end);
 
     for (int i = start; i <= end; i++) {
         const QModelIndex moduleIndex(m_sourceModel->index(i, 0, parent));
@@ -597,8 +597,8 @@ QDataStream & operator <<(QDataStream & os,
                           const BtBookshelfTreeModel::Grouping & o)
 {
     os << o.size();
-    Q_FOREACH(BtBookshelfTreeModel::Group g, o)
-        os << static_cast<int>(g);
+    Q_FOREACH(BtBookshelfTreeModel::Group const g, o)
+        os << static_cast<std::underlying_type<decltype(g)>::type>(g);
     return os;
 }
 
