@@ -4,13 +4,13 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "backend/bookshelfmodel/categoryitem.h"
+#include "categoryitem.h"
 
 
 namespace BookshelfModel {
