@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,11 +13,11 @@
 #ifndef CATEGORYITEM_H
 #define CATEGORYITEM_H
 
-#include "backend/bookshelfmodel/item.h"
+#include "item.h"
 
 #include <QCoreApplication>
-#include "backend/bookshelfmodel/btbookshelfmodel.h"
-#include "backend/drivers/cswordmoduleinfo.h"
+#include "../drivers/cswordmoduleinfo.h"
+#include "btbookshelfmodel.h"
 
 
 namespace BookshelfModel {
@@ -33,13 +33,13 @@ public: /* Methods: */
         return m_category;
     }
 
-    QVariant data(int role = Qt::DisplayRole) const;
+    QVariant data(int role = Qt::DisplayRole) const override;
 
-    inline bool fitFor(const CSwordModuleInfo & module) const {
+    inline bool fitFor(const CSwordModuleInfo & module) const override {
         return module.category() == m_category;
     }
 
-    bool operator<(const Item & other) const;
+    bool operator<(const Item & other) const override;
 
 private: /* Fields: */
 
