@@ -4,15 +4,15 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#include "backend/bookshelfmodel/languageitem.h"
+#include "languageitem.h"
 
-#include "util/geticon.h"
+#include "../../util/cresmgr.h"
 
 
 namespace BookshelfModel {
@@ -24,7 +24,7 @@ QVariant LanguageItem::data(int role) const {
             return m_language->translatedName();
 
         case Qt::DecorationRole:
-            return util::getIcon("flag.svg");
+            return CResMgr::modules::icon_moduleLanguage();
 
         default:
             return Item::data(role);
