@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,10 +13,10 @@
 #ifndef MODULEITEM_H
 #define MODULEITEM_H
 
-#include "backend/bookshelfmodel/item.h"
+#include "item.h"
 
-#include "backend/bookshelfmodel/btbookshelfmodel.h"
-#include "backend/drivers/cswordmoduleinfo.h"
+#include "../drivers/cswordmoduleinfo.h"
+#include "btbookshelfmodel.h"
 
 
 class BtBookshelfTreeModel;
@@ -37,13 +37,13 @@ public: /* Methods: */
       Reimplementation of Item::data() which dispatches all
       requests to the parent model (BtBookshelfTreeModel).
     */
-    virtual QVariant data(int role = Qt::DisplayRole) const;
+    QVariant data(int role = Qt::DisplayRole) const override;
 
     inline CSwordModuleInfo & moduleInfo() const {
         return m_moduleInfo;
     }
 
-    inline virtual bool fitFor(const CSwordModuleInfo &) const {
+    inline bool fitFor(const CSwordModuleInfo &) const override {
         return false;
     }
 
