@@ -2,21 +2,22 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
-#include "backend/drivers/cswordbookmoduleinfo.h"
+#include "cswordbookmoduleinfo.h"
 
-#include "backend/keys/cswordtreekey.h"
+#include "../../util/btassert.h"
+#include "../keys/cswordtreekey.h"
 
 // Sword includes:
 #include <treekey.h>
 #include <treekeyidx.h>
 
 
-CSwordBookModuleInfo::CSwordBookModuleInfo(sword::SWModule * module,
+CSwordBookModuleInfo::CSwordBookModuleInfo(sword::SWModule & module,
                                            CSwordBackend & backend)
     : CSwordModuleInfo(module, backend, CSwordModuleInfo::GenericBook)
     , m_depth(-1)
@@ -47,7 +48,8 @@ void CSwordBookModuleInfo::computeDepth(sword::TreeKeyIdx * const key,
 
 /** Returns a treekey filled with the structure of this module */
 sword::TreeKeyIdx* CSwordBookModuleInfo::tree() const {
-    sword::TreeKeyIdx* treeKey = dynamic_cast<sword::TreeKeyIdx*>((sword::SWKey*) * (module()));
-    Q_ASSERT(treeKey);
+    sword::TreeKeyIdx * const treeKey =
+            dynamic_cast<sword::TreeKeyIdx *>(module().getKey());
+    BT_ASSERT(treeKey);
     return treeKey;
 }
