@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,7 +12,7 @@
 #ifndef CSWORDCOMMENTARYMODULEINFO_H
 #define CSWORDCOMMENTARYMODULEINFO_H
 
-#include "backend/drivers/cswordbiblemoduleinfo.h"
+#include "cswordbiblemoduleinfo.h"
 
 
 /**
@@ -25,14 +25,13 @@ class CSwordCommentaryModuleInfo: public CSwordBibleModuleInfo {
 
     public: /* Methods: */
 
-        inline CSwordCommentaryModuleInfo(sword::SWModule * module,
+        inline CSwordCommentaryModuleInfo(sword::SWModule & module,
                                           CSwordBackend & backend)
             : CSwordBibleModuleInfo(module,
                                     backend,
                                     CSwordModuleInfo::Commentary) {}
 
-        /* Reimplementation of CSwordModuleInfo::isWritable(). */
-        virtual bool isWritable() const;
+        bool isWritable() const override;
 };
 
 #endif
