@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -25,9 +25,9 @@ class TeiToHtml: public sword::TEIHTMLHREF {
     public: /* Methods: */
         TeiToHtml();
 
-        /** Reimplemented from sword::OSISHTMLHREF. */
-        virtual bool handleToken(sword::SWBuf &buf, const char *token,
-                                 sword::BasicFilterUserData *userData);
+        bool handleToken(sword::SWBuf &buf,
+                         const char *token,
+                         sword::BasicFilterUserData *userData) override;
 
     private: /* Methods: */
         void renderReference(const char *osisRef, sword::SWBuf &buf,
