@@ -2,12 +2,12 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
-#include "backend/managers/cswordbackend.h"
+#include "cswordbackend.h"
 
 #include <QDebug>
 #include <QDir>
@@ -15,21 +15,19 @@
 #include <QSet>
 #include <QString>
 #include <QTextCodec>
-#include "backend/config/btconfig.h"
-#include "backend/drivers/cswordbiblemoduleinfo.h"
-#include "backend/drivers/cswordbookmoduleinfo.h"
-#include "backend/drivers/cswordcommentarymoduleinfo.h"
-#include "backend/drivers/cswordlexiconmoduleinfo.h"
-#include "backend/filters/btosismorphsegmentation.h"
-#include "backend/filters/thmltoplain.h"
-#include "btglobal.h"
-#include "util/directory.h"
+#include "../../util/directory.h"
+#include "../btglobal.h"
+#include "../btinstallmgr.h"
+#include "../config/btconfig.h"
+#include "../drivers/cswordbiblemoduleinfo.h"
+#include "../drivers/cswordbookmoduleinfo.h"
+#include "../drivers/cswordcommentarymoduleinfo.h"
+#include "../drivers/cswordlexiconmoduleinfo.h"
 
 // Sword includes:
 #include <encfiltmgr.h>
 #include <filemgr.h>
 #include <rtfhtml.h>
-#include <swdisp.h>
 #include <swfiltermgr.h>
 #include <swfilter.h>
 #include <utilstr.h>
@@ -37,80 +35,89 @@
 
 using namespace Rendering;
 
-CSwordBackend * CSwordBackend::m_instance = 0;
+CSwordBackend * CSwordBackend::m_instance = nullptr;
 
 CSwordBackend::CSwordBackend()
-        : sword::SWMgr(0, 0, false,
+        : sword::SWMgr(nullptr, nullptr, false,
                        new sword::EncodingFilterMgr(sword::ENC_UTF8), true)
         , m_dataModel(this)
-{
-    filterInit();
-}
+{}
 
 CSwordBackend::CSwordBackend(const QString & path, const bool augmentHome)
-        : sword::SWMgr(!path.isEmpty() ? path.toLocal8Bit().constData() : 0,
+        : sword::SWMgr(!path.isEmpty() ? path.toLocal8Bit().constData() : nullptr,
                        false, new sword::EncodingFilterMgr(sword::ENC_UTF8),
                        false, augmentHome)
-{ // don't allow module renaming, because we load from a path
-    filterInit();
-}
+{}
 
 CSwordBackend::~CSwordBackend() {
     shutdownModules();
 }
 
-void CSwordBackend::filterInit() {
-    // HACK: replace Sword's OSISMorphSegmentation filter, seems to be buggy, ours works
-    if (sword::SWOptionFilter * const filter = optionFilters["OSISMorphSegmentation"]) {
-        cleanupFilters.remove(filter);
-        optionFilters.erase("OSISMorphSegmentation");
-        delete filter;
-    }
-    sword::SWOptionFilter * const tmpFilter = new Filters::BtOSISMorphSegmentation();
-    optionFilters.insert(sword::OptionFilterMap::value_type("OSISMorphSegmentation", tmpFilter));
-    cleanupFilters.push_back(tmpFilter);
-
-    // HACK: replace Sword's ThML strip filter with our own version
-    // Remove this hack as soon as Sword is fixed
-    cleanupFilters.remove(thmlplain);
-    delete thmlplain;
-    thmlplain = new Filters::ThmlToPlain();
-    cleanupFilters.push_back(thmlplain);
+BtModuleList CSwordBackend::moduleList(CSwordModuleInfo::ModuleType type) const
+{
+    BtModuleList l;
+    Q_FOREACH(CSwordModuleInfo * m, moduleList())
+        if(m->type() == type)
+            l.append(m);
+    return l;
 }
 
-QList<CSwordModuleInfo *> CSwordBackend::takeModulesFromList(const QStringList & names) {
-    QList<CSwordModuleInfo *> list;
-    Q_FOREACH (const QString & name, names) {
-        CSwordModuleInfo * const mInfo = findModuleByName(name);
-        if (mInfo) {
-            m_dataModel.removeModule(mInfo);
-            list.append(mInfo);
+void CSwordBackend::uninstallModules(BtConstModuleSet const & toBeDeleted) {
+    if (toBeDeleted.empty())
+        return;
+    m_dataModel.removeModules(toBeDeleted);
+    emit sigSwordSetupChanged(RemovedModules);
+
+    BtInstallMgr installMgr;
+    QMap<QString, sword::SWMgr *> mgrDict; // Maps config paths to SWMgr objects
+    for (CSwordModuleInfo const * const mInfo : toBeDeleted) {
+        // Find the install path for the sword manager:
+        QString dataPath = mInfo->config(CSwordModuleInfo::DataPath);
+        if (dataPath.left(2) == "./")
+            dataPath = dataPath.mid(2);
+
+        QString prefixPath =
+            mInfo->config(CSwordModuleInfo::AbsoluteDataPath) + "/";
+        if (prefixPath.contains(dataPath)) {
+            // Remove module part to get the prefix path:
+            prefixPath = prefixPath.remove(prefixPath.indexOf(dataPath),
+                                           dataPath.length());
+        } else { // This is an error, should not happen
+            qWarning() << "Removing" << mInfo->name()
+                       << "didn't succeed because the absolute path"
+                       << prefixPath << "didn't contain the data path"
+                       << dataPath;
+            continue; // don't remove this, go to next of the for loop
         }
+
+        // Create the sword manager and remove the module
+        sword::SWMgr * mgr = mgrDict[prefixPath];
+        if (!mgr) { // Create new mgr if it's not yet available
+            mgrDict.insert(prefixPath,
+                           new sword::SWMgr(prefixPath.toLocal8Bit()));
+            mgr = mgrDict[prefixPath];
+        }
+        qDebug() << "Removing the module" << mInfo->name() << "...";
+        installMgr.removeModule(mgr, mInfo->module().getName());
     }
-    if (!list.isEmpty())
-        emit sigSwordSetupChanged(RemovedModules);
-    return list;
+    qDeleteAll(toBeDeleted);
+    qDeleteAll(mgrDict);
+    mgrDict.clear();
 }
 
 QList<CSwordModuleInfo *> CSwordBackend::getPointerList(const QStringList & names) const {
     QList<CSwordModuleInfo *> list;
-    Q_FOREACH (const QString & name, names) {
-        CSwordModuleInfo * const mInfo = findModuleByName(name);
-        if (mInfo)
+    Q_FOREACH (const QString & name, names)
+        if (CSwordModuleInfo * const mInfo = findModuleByName(name))
             list.append(mInfo);
-    }
     return list;
 }
 
-QList<const CSwordModuleInfo *> CSwordBackend::getConstPointerList(
-        const QStringList & names) const
-{
-    QList<const CSwordModuleInfo *> list;
-    Q_FOREACH (const QString & name, names) {
-        const CSwordModuleInfo * const mInfo = findModuleByName(name);
-        if (mInfo)
+BtConstModuleList CSwordBackend::getConstPointerList(const QStringList & names) const {
+    BtConstModuleList list;
+    Q_FOREACH (const QString & name, names)
+        if (CSwordModuleInfo const * const mInfo = findModuleByName(name))
             list.append(mInfo);
-    }
     return list;
 }
 
@@ -125,21 +132,22 @@ CSwordBackend::LoadError CSwordBackend::initModules(const SetupChangedReason rea
 
     for (sword::ModMap::iterator it = Modules.begin(); it != end; ++it) {
         sword::SWModule * const curMod = it->second;
+        BT_ASSERT(curMod);
         CSwordModuleInfo * newModule;
 
         const char * const modType = curMod->getType();
         if (!strcmp(modType, "Biblical Texts")) {
-            newModule = new CSwordBibleModuleInfo(curMod, *this);
-            newModule->module()->setDisplay(&m_chapterDisplay);
+            newModule = new CSwordBibleModuleInfo(*curMod, *this);
+            newModule->setDisplay(&m_chapterDisplay);
         } else if (!strcmp(modType, "Commentaries")) {
-            newModule = new CSwordCommentaryModuleInfo(curMod, *this);
-            newModule->module()->setDisplay(&m_entryDisplay);
+            newModule = new CSwordCommentaryModuleInfo(*curMod, *this);
+            newModule->setDisplay(&m_entryDisplay);
         } else if (!strcmp(modType, "Lexicons / Dictionaries")) {
-            newModule = new CSwordLexiconModuleInfo(curMod, *this);
-            newModule->module()->setDisplay(&m_entryDisplay);
+            newModule = new CSwordLexiconModuleInfo(*curMod, *this);
+            newModule->setDisplay(&m_entryDisplay);
         } else if (!strcmp(modType, "Generic Books")) {
-            newModule = new CSwordBookModuleInfo(curMod, *this);
-            newModule->module()->setDisplay(&m_bookDisplay);
+            newModule = new CSwordBookModuleInfo(*curMod, *this);
+            newModule->setDisplay(&m_bookDisplay);
         } else {
             continue;
         }
@@ -156,7 +164,7 @@ CSwordBackend::LoadError CSwordBackend::initModules(const SetupChangedReason rea
     }
 
     // Unlock modules if keys are present:
-    Q_FOREACH(CSwordModuleInfo * mod, m_dataModel.moduleList()) {
+    Q_FOREACH(CSwordModuleInfo const * const mod, m_dataModel.moduleList()) {
         if (mod->isEncrypted()) {
             const QString unlockKey = btConfig().getModuleEncryptionKey(mod->name());
             if (!unlockKey.isNull())
@@ -208,7 +216,7 @@ void CSwordBackend::shutdownModules() {
      * modules. If these modules are removed, the filters need to be removed as well,
      * so that they are re-created for the new module objects.
      */
-    typedef sword::FilterMap::const_iterator FMCI;
+    using FMCI = sword::FilterMap::const_iterator;
     for (FMCI it = cipherFilters.begin(); it != cipherFilters.end(); ++it) {
         //Delete the Filter and remove it from the cleanup list
         cleanupFilters.remove(it->second);
@@ -258,24 +266,24 @@ void CSwordBackend::setFilterOptions(const FilterOptions & options) {
 }
 
 CSwordModuleInfo * CSwordBackend::findModuleByDescription(const QString & description) const {
-    Q_FOREACH (CSwordModuleInfo * mod, m_dataModel.moduleList())
+    Q_FOREACH(CSwordModuleInfo * const mod, m_dataModel.moduleList())
         if (mod->config(CSwordModuleInfo::Description) == description)
             return mod;
-    return 0;
+    return nullptr;
 }
 
 CSwordModuleInfo * CSwordBackend::findModuleByName(const QString & name) const {
-    Q_FOREACH (CSwordModuleInfo * mod, m_dataModel.moduleList())
+    Q_FOREACH(CSwordModuleInfo * const mod, m_dataModel.moduleList())
         if (mod->name() == name)
             return mod;
-    return 0;
+    return nullptr;
 }
 
 CSwordModuleInfo * CSwordBackend::findSwordModuleByPointer(const sword::SWModule * const swmodule) const {
-    Q_FOREACH (CSwordModuleInfo * mod, m_dataModel.moduleList())
-        if (mod->module() == swmodule)
+    Q_FOREACH(CSwordModuleInfo * const mod, m_dataModel.moduleList())
+        if (&mod->module() == swmodule)
             return mod;
-    return 0;
+    return nullptr;
 }
 
 QString CSwordBackend::optionName(const CSwordModuleInfo::FilterTypes option) {
@@ -377,13 +385,13 @@ const QString CSwordBackend::booknameLanguage(const QString & language) {
         // Use what sword returns, language may be different.
         const QByteArray newLocaleName(QString(sword::LocaleMgr::getSystemLocaleMgr()->getDefaultLocaleName()).toUtf8());
 
-        Q_FOREACH (CSwordModuleInfo * mod, m_dataModel.moduleList()) {
+        Q_FOREACH(CSwordModuleInfo const * const mod, m_dataModel.moduleList()) {
             if (mod->type() == CSwordModuleInfo::Bible
                 || mod->type() == CSwordModuleInfo::Commentary)
             {
                 // Create a new key, it will get the default bookname language:
-                typedef sword::VerseKey VK;
-                VK & vk = *static_cast<VK *>(mod->module()->getKey());
+                using VK = sword::VerseKey;
+                VK & vk = *static_cast<VK *>(mod->module().getKey());
                 vk.setLocale(newLocaleName.constData());
             }
         }
@@ -399,7 +407,7 @@ void CSwordBackend::reloadModules(const SetupChangedReason reason) {
 
     if (myconfig) { // force reload on config object because we may have changed the paths
         delete myconfig;
-        config = myconfig = 0;
+        config = myconfig = nullptr;
         // we need to call findConfig to make sure that augPaths are reloaded
         findConfig(&configType, &prefixPath, &configPath, &augPaths, &sysConfig);
         // now re-read module configuration files
@@ -414,8 +422,8 @@ void CSwordBackend::reloadModules(const SetupChangedReason reason) {
 // Get one or more shared sword config (sword.conf) files
 QStringList CSwordBackend::getSharedSwordConfigFiles() const {
 #ifdef Q_OS_WIN
-    //  %ALLUSERSPROFILE%\Sword\sword.conf
-    return QStringList(util::directory::convertDirSeparators(QString(getenv("SWORD_PATH"))) += "/Sword/sword.conf");
+    //  %ProgramData%\Sword\sword.conf
+    return QStringList(util::directory::convertDirSeparators(qgetenv("SWORD_PATH")) += "/Sword/sword.conf");
 #else
     // /etc/sword.conf, /usr/local/etc/sword.conf
     return QString(globalConfPath).split(":");
@@ -434,7 +442,7 @@ QString CSwordBackend::getPrivateSwordConfigFile() const {
 // Return a list of used Sword dirs. Useful for the installer.
 QStringList CSwordBackend::swordDirList() const {
     namespace DU = util::directory;
-    typedef QStringList::const_iterator SLCI;
+    using SLCI = QStringList::const_iterator;
 
     // Get the set of sword directories that could contain modules:
     QSet<QString> swordDirSet;
@@ -457,7 +465,7 @@ QStringList CSwordBackend::swordDirList() const {
           private sword.conf will have it. The user could decide to delete this
           shared path and it will not automatically come back.
         */
-        swordDirSet << DU::convertDirSeparators(QString(getenv("SWORD_PATH")));
+        swordDirSet << DU::convertDirSeparators(qgetenv("SWORD_PATH"));
 #endif
     }
 
@@ -474,7 +482,7 @@ QStringList CSwordBackend::swordDirList() const {
         swordDirSet << QDir(QTextCodec::codecForLocale()->toUnicode(conf["Install"]["DataPath"].c_str())).absolutePath();
 
         const sword::ConfigEntMap group(conf["Install"]);
-        typedef sword::ConfigEntMap::const_iterator CEMCI;
+        using CEMCI = sword::ConfigEntMap::const_iterator ;
         for (std::pair<CEMCI, CEMCI> its = group.equal_range("AugmentPath");
              its.first != its.second;
              ++(its.first))
@@ -495,8 +503,7 @@ void CSwordBackend::deleteOrphanedIndices() {
     Q_FOREACH(const QString & entry, entries) {
         if (entry == "." || entry == "..")
             continue;
-        CSwordModuleInfo * const module = findModuleByName(entry);
-        if (module) { //mod exists
+        if (CSwordModuleInfo * const module = findModuleByName(entry)) {
             if (!module->hasIndex()) { //index files found, but wrong version etc.
                 qDebug() << "deleting outdated index for module" << entry;
                 CSwordModuleInfo::deleteIndexForModule(entry);
