@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -13,18 +13,19 @@
 #define CENTRYDISPLAY_H
 
 #include <QString>
+#include "../drivers/btmodulelist.h"
+#include "ctextrendering.h"
 
 // Sword includes:
-#include <swdisp.h>
 #include <swmodule.h>
 
-class CSwordModuleInfo;
+
 struct DisplayOptions;
 struct FilterOptions;
 
 namespace Rendering {
 
-class CEntryDisplay: public sword::SWDisplay {
+class CEntryDisplay {
 
     public: /* Methods: */
 
@@ -32,12 +33,18 @@ class CEntryDisplay: public sword::SWDisplay {
           \returns the rendered text using the modules in the list and using the
                    key parameter.
         */
-        virtual const QString text(const QList<const CSwordModuleInfo*> &modules,
+        virtual const QString text(const BtConstModuleList &modules,
                                    const QString &key,
                                    const DisplayOptions &displayOptions,
                                    const FilterOptions &filterOptions);
 
-        virtual char display(sword::SWModule& mod) { (void)mod; return 'c';}
+    const QString textKeyRendering(const BtConstModuleList &modules,
+                               const QString &key,
+                               const DisplayOptions &displayOptions,
+                               const FilterOptions &filterOptions,
+                               CTextRendering::KeyTreeItem::Settings::KeyRenderingFace keyRendering);
+
+        virtual char display(CSwordModuleInfo & mod) { (void)mod; return 'c';}
 
 }; /* class CEntryDisplay */
 
