@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,8 +12,8 @@
 #ifndef RENDERINGCPLAINTEXTEXPORTRENDERING_H
 #define RENDERINGCPLAINTEXTEXPORTRENDERING_H
 
-#include "backend/rendering/chtmlexportrendering.h"
-#include "backend/config/btconfig.h"
+#include "../config/btconfig.h"
+#include "chtmlexportrendering.h"
 
 
 namespace Rendering {
@@ -34,8 +34,8 @@ class CPlainTextExportRendering: public CHTMLExportRendering {
 
     protected: /* Methods: */
 
-        virtual QString renderEntry(const KeyTreeItem &item, CSwordKey * key = 0);
-        virtual QString finishText(const QString &text, const KeyTree &tree);
+        QString renderEntry(const KeyTreeItem &item, CSwordKey * key = nullptr) override;
+        QString finishText(const QString &text, const KeyTree &tree) override;
 
 }; /* class CPlainTextExportRendering */
 
