@@ -32,6 +32,7 @@
 #include "frontend/display/btfindwidget.h"
 #include "frontend/displaywindow/btactioncollection.h"
 #include "frontend/displaywindow/btmodulechooserbar.h"
+#include "frontend/keychooser/ckeychooser.h"
 #include "frontend/bookmarks/cbookmarkindex.h"
 #include "frontend/settingsdialogs/cdisplaysettings.h"
 #include "util/btassert.h"
@@ -313,6 +314,13 @@ void BibleTime::clearMdiToolBars() {
     m_formatToolBar->clear();
 }
 
+CKeyChooser* BibleTime::keyChooser() const {
+    BT_ASSERT(m_navToolBar);
+
+    CKeyChooser* keyChooser = m_navToolBar->findChild<CKeyChooser*>();
+    return keyChooser;
+}
+
 void BibleTime::createMenuAndToolBar()
 {
     // Create menubar
@@ -792,7 +800,7 @@ void BibleTime::initConnections() {
 void BibleTime::initSwordConfigFile() {
 // On Windows the sword.conf must be created before the initialization of sword
 // It will contain the LocalePath which is used for sword locales
-// It also contains a DataPath to the %ALLUSERSPROFILE%\Sword directory
+// It also contains a DataPath to the %ProgramData%\Sword directory
 // If this is not done here, the sword locales.d won't be found
 #ifdef Q_OS_WIN
     QString configFile = util::directory::getUserHomeSwordDir().filePath("sword.conf");
