@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -27,7 +27,7 @@
 #include "frontend/btaboutdialog.h"
 #include "frontend/cinfodisplay.h"
 #include "frontend/cmdiarea.h"
-#include "frontend/bookshelfmanager/btmodulemanagerdialog.h"
+#include "frontend/bookshelfwizard/btbookshelfwizard.h"
 #include "frontend/display/btfindwidget.h"
 #include "frontend/displaywindow/btmodulechooserbar.h"
 #include "frontend/displaywindow/cdisplaywindow.h"
@@ -35,6 +35,8 @@
 #include "frontend/searchdialog/csearchdialog.h"
 #include "frontend/settingsdialogs/cconfigurationdialog.h"
 #include "frontend/tips/bttipdialog.h"
+#include "util/btassert.h"
+#include "util/btconnect.h"
 #include "util/directory.h"
 
 
@@ -42,14 +44,15 @@
 void BibleTime::slotSettingsOptions() {
     qDebug() << "BibleTime::slotSettingsOptions";
     CConfigurationDialog *dlg = new CConfigurationDialog(this, m_actionCollection);
-    QObject::connect(dlg, SIGNAL(signalSettingsChanged()), this, SLOT(slotSettingsChanged()) );
+    BT_CONNECT(dlg,  SIGNAL(signalSettingsChanged()),
+               this, SLOT(slotSettingsChanged()) );
 
     dlg->show();
 }
 
 /** Save the settings, used when no settings have been saved before **/
 void BibleTime::saveConfigSettings() {
-    CConfigurationDialog* dlg = new CConfigurationDialog(this, 0);
+    CConfigurationDialog* dlg = new CConfigurationDialog(this, nullptr);
     dlg->save();
     delete dlg;
 }
@@ -57,7 +60,7 @@ void BibleTime::saveConfigSettings() {
 /** Is called when settings in the optionsdialog were changed (ok or apply) */
 void BibleTime::slotSettingsChanged() {
     qDebug() << "BibleTime::slotSettingsChanged";
-    const QString language = btConfig().value<QString>("language", QLocale::system().name());
+    const QString language = btConfig().value<QString>("GUI/booknameLanguage", QLocale::system().name());
     CSwordBackend::instance()->booknameLanguage(language);
 
 // \todo update the bookmarks after Bible bookname language has been changed
@@ -70,25 +73,21 @@ void BibleTime::slotSettingsChanged() {
 //         ++it;
 //     }
 
-    refreshBibleTimeAccel();
+    m_actionCollection->readShortcuts("Application shortcuts");
     refreshDisplayWindows();
     refreshProfileMenus();
     qDebug() << "BibleTime::slotSettingsChanged";
 }
 
-/** Opens the sword setup dialog of BibleTime. */
-void BibleTime::slotSwordSetupDialog() {
-    BtModuleManagerDialog *dlg = BtModuleManagerDialog::getInstance(this);
-
-    dlg->showNormal();
-    dlg->show();
-    dlg->raise();
-    dlg->activateWindow();
+/** Opens the bookshelf wizard. */
+void BibleTime::slotBookshelfWizard() {
+    BtBookshelfWizard dlg(BibleTime::instance());
+    dlg.exec();
 }
 
 /** Is called just before the window menu is shown. */
 void BibleTime::slotWindowMenuAboutToShow() {
-    Q_ASSERT(m_windowMenu);
+    BT_ASSERT(m_windowMenu);
 
     const int numSubWindows = m_mdi->subWindowList().count();
     m_windowCloseAction->setEnabled(numSubWindows);
@@ -104,21 +103,22 @@ void BibleTime::slotWindowMenuAboutToShow() {
 
 /** Is called just before the open windows menu is shown. */
 void BibleTime::slotOpenWindowsMenuAboutToShow() {
-    Q_ASSERT(m_openWindowsMenu);
+    BT_ASSERT(m_openWindowsMenu);
 
     m_openWindowsMenu->clear();
     Q_FOREACH (QMdiSubWindow * const window, m_mdi->usableWindowList()) {
         QAction *openWindowAction = m_openWindowsMenu->addAction(window->windowTitle());
         openWindowAction->setCheckable(true);
         openWindowAction->setChecked(window == m_mdi->activeSubWindow());
-        connect(openWindowAction, SIGNAL(triggered()), m_windowMapper, SLOT(map()));
+        BT_CONNECT(openWindowAction, SIGNAL(triggered()),
+                   m_windowMapper,   SLOT(map()));
         m_windowMapper->setMapping(openWindowAction, window);
     }
 }
 
 /** This slot is connected with the windowAutoTileAction object */
 void BibleTime::slotUpdateWindowArrangementActions(QAction * trigerredAction) {
-    Q_ASSERT(trigerredAction);
+    BT_ASSERT(trigerredAction);
 
     if (trigerredAction == m_windowAutoTileVerticalAction) {
         m_mdi->setMDIArrangementMode(CMDIArea::ArrangementModeTileVertical);
@@ -141,7 +141,7 @@ void BibleTime::slotUpdateWindowArrangementActions(QAction * trigerredAction) {
         btConfig().setSessionValue("GUI/alignmentMode", autoCascade);
     }
     else {
-        Q_ASSERT(trigerredAction == m_windowManualModeAction
+        BT_ASSERT(trigerredAction == m_windowManualModeAction
                  || trigerredAction == m_windowTileAction
                  || trigerredAction == m_windowCascadeAction
                  || trigerredAction == m_windowTileVerticalAction
@@ -187,7 +187,7 @@ void BibleTime::slotTileHorizontal() {
 
 /** Shows/hides the toolbar */
 void BibleTime::slotToggleMainToolbar() {
-    Q_ASSERT(m_mainToolBar);
+    BT_ASSERT(m_mainToolBar);
     bool currentState = btConfig().sessionValue<bool>("GUI/showMainToolbar", true);
     btConfig().setSessionValue("GUI/showMainToolbar", !currentState);
     if ( m_showMainWindowToolbarAction->isChecked()) {
@@ -282,11 +282,11 @@ void BibleTime::slotSetActiveSubWindow(QWidget* window) {
 
 void BibleTime::slotSearchModules() {
     //get the modules of the open windows
-    QList<const CSwordModuleInfo*> modules;
+    BtConstModuleList modules;
 
     Q_FOREACH (const QMdiSubWindow * const subWindow, m_mdi->subWindowList()) {
         const CDisplayWindow * const w = dynamic_cast<CDisplayWindow*>(subWindow->widget());
-        if (w != 0) {
+        if (w != nullptr) {
             modules << w->modules();
         }
     }
@@ -295,7 +295,7 @@ void BibleTime::slotSearchModules() {
 
 void BibleTime::slotActiveWindowChanged(QMdiSubWindow* window)
 {
-    if (window == 0)
+    if (window == nullptr)
         m_findWidget->setVisible(false);
 }
 
@@ -303,7 +303,7 @@ void BibleTime::slotActiveWindowChanged(QMdiSubWindow* window)
  * Call CSearchDialog::openDialog with only the default bible module
  */
 void BibleTime::slotSearchDefaultBible() {
-    QList<const CSwordModuleInfo*> module;
+    BtConstModuleList module;
     CSwordModuleInfo* bible = btConfig().getDefaultSwordModuleByType("standardBible");
     if (bible) {
         module.append(bible);
@@ -357,15 +357,15 @@ void BibleTime::saveProfile() {
 }
 
 void BibleTime::loadProfile(QAction * action) {
-    Q_ASSERT(action);
+    BT_ASSERT(action);
     QVariant keyProperty = action->property("ProfileKey");
-    Q_ASSERT(keyProperty.type() == QVariant::String);
-    Q_ASSERT(btConfig().sessionNames().contains(keyProperty.toString()));
+    BT_ASSERT(keyProperty.type() == QVariant::String);
+    BT_ASSERT(btConfig().sessionNames().contains(keyProperty.toString()));
     loadProfile(keyProperty.toString());
 }
 
 void BibleTime::loadProfile(const QString & profileKey) {
-    Q_ASSERT(btConfig().sessionNames().contains(profileKey));
+    BT_ASSERT(btConfig().sessionNames().contains(profileKey));
 
     // do nothing if requested session is the current session
     if (profileKey == btConfig().currentSessionKey())
@@ -387,7 +387,7 @@ namespace {
 
 /// Helper object for reloadProfile()
 struct WindowLoadStatus {
-    inline WindowLoadStatus() : window(0) {}
+    inline WindowLoadStatus() : window(nullptr) {}
     QStringList failedModules;
     QList<CSwordModuleInfo*> okModules;
     CDisplayWindow * window;
@@ -396,8 +396,8 @@ struct WindowLoadStatus {
 } // anonymous namespace
 
 void BibleTime::reloadProfile() {
-    typedef CMDIArea::MDIArrangementMode MAM;
-    typedef CPlainWriteWindow::WriteWindowType WWT;
+    using MAM = CMDIArea::MDIArrangementMode;
+    using WWT = CPlainWriteWindow::WriteWindowType;
     using message::setQActionCheckedNoTrigger;
 
     // Cache pointer to config:
@@ -427,11 +427,12 @@ void BibleTime::reloadProfile() {
     setQActionCheckedNoTrigger(m_showFormatToolbarAction, conf.sessionValue<bool>("GUI/showFormatToolbarButtons", true));
     setQActionCheckedNoTrigger(m_toolbarsInEachWindow, conf.sessionValue<bool>("GUI/showToolbarsInEachWindow", true));
 
-    m_mdi->setMDIArrangementMode(static_cast<MAM>(conf.sessionValue<int>("MainWindow/MDIArrangementMode")));
+    m_mdi->setMDIArrangementMode(static_cast<MAM>(
+                                     conf.sessionValue<int>("MainWindow/MDIArrangementMode",CMDIArea::ArrangementModeTile)));
 
     m_findWidget->setVisible(conf.sessionValue<bool>("FindIsVisible", false));
 
-    QWidget * focusWindow = 0;
+    QWidget * focusWindow = nullptr;
     QMap<QString, WindowLoadStatus> failedWindows;
     Q_FOREACH (const QString & w,
                conf.sessionValue<QStringList>("windowsList"))
@@ -462,7 +463,7 @@ void BibleTime::reloadProfile() {
             failedWindows.insert(w, wls);
 
         // Try to respawn the window:
-        Q_ASSERT(!wls.window);
+        BT_ASSERT(!wls.window);
         const QString key = conf.sessionValue<QString>(windowGroup + "key");
         WWT wwt = static_cast<WWT>(conf.sessionValue<int>(windowGroup + "writeWindowType", 0));
         if (wwt > 0) {
@@ -505,10 +506,10 @@ void BibleTime::reloadProfile() {
 }
 
 void BibleTime::deleteProfile(QAction* action) {
-    Q_ASSERT(action);
+    BT_ASSERT(action);
     QVariant keyProperty = action->property("ProfileKey");
-    Q_ASSERT(keyProperty.type() == QVariant::String);
-    Q_ASSERT(btConfig().sessionNames().contains(keyProperty.toString()));
+    BT_ASSERT(keyProperty.type() == QVariant::String);
+    BT_ASSERT(btConfig().sessionNames().contains(keyProperty.toString()));
 
     /// \todo Ask for confirmation
     btConfig().deleteSession(keyProperty.toString());
@@ -561,8 +562,8 @@ void BibleTime::saveToNewProfile() {
 
 /** Slot to refresh the saved profile and load profile menus. */
 void BibleTime::refreshProfileMenus() {
-    typedef BtConfig::SessionNamesHashMap SNHM;
-    typedef SNHM::const_iterator SNHMCI;
+    using SNHM = BtConfig::SessionNamesHashMap;
+    using SNHMCI = SNHM::const_iterator;
 
     m_windowLoadProfileMenu->clear();
     m_windowDeleteProfileMenu->clear();
