@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -29,8 +29,8 @@ class BTAboutModuleDialog: public QDialog {
     public: /* Methods: */
 
         BTAboutModuleDialog(const CSwordModuleInfo *moduleInfo,
-                            QWidget *parent = 0,
-                            Qt::WindowFlags flags = 0);
+                            QWidget *parent = nullptr,
+                            Qt::WindowFlags flags = nullptr);
 
     protected: /* Methods: */
 
