@@ -57,7 +57,12 @@ CDisplayWindow::CDisplayWindow(const QList<CSwordModuleInfo *> & modules, CMDIAr
         m_popupMenu(nullptr),
         m_displayWidget(nullptr),
         m_history(nullptr) {
-    setAttribute(Qt::WA_DeleteOnClose); //we want to destroy this window when it is closed
+
+    // Cannot delete on close. QMdiSubWindow and this window work
+    // as pairs. They must be deleted in a specific order.
+    // QMdiSubWindow handles this procedure.
+    //setAttribute(Qt::WA_DeleteOnClose);
+
     m_actionCollection = new BtActionCollection(this);
     setModules(modules);
 
@@ -288,7 +293,7 @@ void CDisplayWindow::reload(CSwordBackend::SetupChangedReason) {
 
     lookup();
 
-    m_actionCollection->readShortcuts("DisplayWindow shortcuts");
+    m_actionCollection->readShortcuts("Displaywindow shortcuts");
     m_actionCollection->readShortcuts("Readwindow shortcuts");
     emit sigModuleListSet(m_modules);
 }
@@ -583,6 +588,12 @@ void CDisplayWindow::printAnchorWithText() {
 }
 
 void CDisplayWindow::setFocusKeyChooser() {
-    keyChooser()->setFocus();
+    if (btConfig().sessionValue<bool>("GUI/showToolbarsInEachWindow", true)) {
+        keyChooser()->setFocus();
+    } else {
+        CKeyChooser* mainWinKeyChooser = btMainWindow()->keyChooser();
+        if (mainWinKeyChooser)
+            mainWinKeyChooser->setFocus();
+    }
 }
 
