@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -14,22 +14,20 @@
 
 #include <QGraphicsRectItem>
 
-
-class CSwordModuleInfo;
+#include "backend/drivers/btmodulelist.h"
 
 namespace Search {
 
 class CSearchAnalysisLegendItem : public QGraphicsRectItem {
     public: /* Methods: */
-        inline CSearchAnalysisLegendItem(const QList<const CSwordModuleInfo*> &modules)
+        inline CSearchAnalysisLegendItem(const BtConstModuleList &modules)
             : m_moduleList(modules) {}
 
     private: /* Methods: */
-        /** Reimplementation of QGraphicsItem::paint. */
-        virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*);
+        void paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*) override;
 
     private: /* Fields: */
-        QList<const CSwordModuleInfo*> m_moduleList;
+        BtConstModuleList m_moduleList;
 
 };
 
