@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,14 +12,13 @@
 #ifndef CCONFIGURATIONDIALOG_H
 #define CCONFIGURATIONDIALOG_H
 
-#include "frontend/bookshelfmanager/btconfigdialog.h"
+#include "btconfigdialog.h"
 
 
 class BtActionCollection;
 class CAcceleratorSettingsPage;
 class CDisplaySettingsPage;
 class BtFontSettingsPage;
-class BtLanguageSettingsPage;
 class CSwordSettingsPage;
 class QAbstractButton;
 class QDialogButtonBox;
@@ -41,7 +40,6 @@ class CConfigurationDialog : public BtConfigDialog {
         CSwordSettingsPage* m_swordPage;
         CAcceleratorSettingsPage* m_acceleratorsPage;
         BtFontSettingsPage* m_fontsPage;
-        BtLanguageSettingsPage* m_languagesPage;
         QDialogButtonBox* m_bbox;
 
         // Load the settings from the resource file
