@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,7 +12,7 @@
 #ifndef CDISPLAYSETTINGS_H
 #define CDISPLAYSETTINGS_H
 
-#include "frontend/bookshelfmanager/btconfigdialog.h"
+#include "btconfigdialog.h"
 
 #include <QWidget>
 
@@ -21,7 +21,7 @@ class CConfigurationDialog;
 class QCheckBox;
 class QComboBox;
 class QLabel;
-class QWebView;
+class BtWebEngineView;
 
 class CDisplaySettingsPage: public BtConfigDialog::Page {
 
@@ -29,10 +29,12 @@ class CDisplaySettingsPage: public BtConfigDialog::Page {
 
     public: /* Methods: */
 
-        CDisplaySettingsPage(CConfigurationDialog *parent = 0);
+        CDisplaySettingsPage(CConfigurationDialog *parent = nullptr);
 
         void save();
 
+        static void resetLanguage();
+
     protected: /* Methods: */
 
         void retranslateUi();
@@ -41,13 +43,21 @@ class CDisplaySettingsPage: public BtConfigDialog::Page {
         /** Update the style preview widget. */
         void updateStylePreview();
 
+    private: /* Methods: */
+
+        static QVector<QString> bookNameAbbreviationsTryVector();
+        void initSwordLocaleCombo();
+
     private: /* Fields: */
 
+        QLabel* m_showLogoLabel;
         QCheckBox* m_showLogoCheck;
-        QLabel *m_explanationLabel;
+        QLabel *m_languageNamesLabel;
+        QComboBox* m_swordLocaleCombo;
+        QLabel *m_transifexLabel;
         QComboBox* m_styleChooserCombo;
         QLabel *m_availableLabel;
-        QWebView* m_stylePreviewViewer;
+        BtWebEngineView* m_stylePreviewViewer;
         QLabel *m_previewLabel;
 
 };
