@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -12,7 +12,8 @@
 #ifndef CSWORDSETTINGS_H
 #define CSWORDSETTINGS_H
 
-#include "frontend/bookshelfmanager/btconfigdialog.h"
+#include "btconfigdialog.h"
+
 #include <QWidget>
 
 
@@ -26,7 +27,7 @@ class CSwordSettingsPage: public BtConfigDialog::Page {
 
     public: /* Methods: */
 
-        CSwordSettingsPage(CConfigurationDialog * parent = 0);
+        CSwordSettingsPage(CConfigurationDialog * parent = nullptr);
 
         void save();
 
