@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -20,7 +20,7 @@ class BibleTime : public QObject {
     Q_OBJECT
 
 public:
-    BibleTime(QObject* parent = 0);
+    BibleTime(QObject* parent = nullptr);
 
 private:
     void initBackends();
