@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,8 +14,6 @@
 #define BIBLETIMEAPP_H
 
 #include <QGuiApplication>
-#include <QIcon>
-#include <QMap>
 
 
 /**
@@ -31,25 +29,23 @@ class BibleTimeApp : public QGuiApplication {
         BibleTimeApp(int &argc, char **argv);
         ~BibleTimeApp();
 
-        inline void startInit() { m_init = true; }
+        inline void startInit(bool const debugMode = false) {
+            m_init = true;
+            m_debugMode = debugMode;
+        }
+
         bool initBtConfig();
         bool initDisplayTemplateManager();
 
-        /**
-           \param[in] name the name of the icon to return.
-           \returns a reference to the icon with the given name or to a NULL
-                    icon if no such icon is found.
-         */
-        const QIcon & getIcon(const QString & name) const;
+        bool debugMode() const { return m_debugMode; }
 
     private: /* Fields: */
 
-        mutable QMap<QString, QIcon> m_iconCache;
-        const QIcon m_nullIcon;
         bool m_init;
+        bool m_debugMode;
 
 };
 
-#define bApp (static_cast<BibleTimeApp *>(QCoreApplication::instance()))
+#define btApp (static_cast<BibleTimeApp *>(BibleTimeApp::instance()))
 
 #endif
