@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -21,7 +21,7 @@ namespace btm {
 class InstallSources : public QObject {
         Q_OBJECT
     public:
-        InstallSources(QObject *parent = 0);
+        InstallSources(QObject *parent = nullptr);
 
         ~InstallSources();
 
