@@ -4,7 +4,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -24,11 +24,14 @@ class InstallSourcesManager :public QObject {
     Q_OBJECT
 
 public:
-    InstallSourcesManager(QObject* parent = 0);
+    InstallSourcesManager(QObject* parent = nullptr);
     ~InstallSourcesManager();
 
     void refreshSources();
 
+signals:
+    void sourcesUpdated();
+
 private slots:
     void cancel();
     void percentComplete(int percent, const QString& title);
