@@ -2,7 +2,7 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
@@ -24,6 +24,15 @@ int showWarning(QWidget * /*parent*/,
     return 0;
 }
 
+int showCritical(QWidget * /*parent*/,
+                const QString & /*title*/,
+                const QString & /*text*/,
+                QMessageBox::StandardButtons /*buttons*/,
+                QMessageBox::StandardButton /*defaultButton*/) {
+    // TODO - implement showCritical
+    return 0;
+}
+
 int showQuestion(QWidget * /*parent*/,
                 const QString & /*title*/,
                 const QString & /*text*/,
