@@ -4,15 +4,12 @@
 *
 * This file is part of BibleTime's source code, http://www.bibletime.info/.
 *
-* Copyright 1999-2014 by the BibleTime developers.
+* Copyright 1999-2016 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License version 2.0.
 *
 **********/
 
-#include <QString>
 #include <QStringList>
 
-bool equalModuleCategories(const QString& name1, const QString& name2);
-
-int  leftLikeParallelModules(const QStringList modules);
 
+int leftLikeParallelModules(QStringList const & modules);
