@@ -18,6 +18,9 @@
 #include <QFileInfoList>
 #include <QLocale>
 #include "btassert.h"
+#ifdef Q_OS_WIN32
+#include <windows.h>
+#endif
 
 
 namespace util {
@@ -104,14 +107,14 @@ bool initDirectoryCache() {
 #endif
 
 #if !defined Q_OS_WINCE && !defined BT_MOBILE && !defined Q_OS_WINRT
-    cachedSharedSwordDir.reset(new QDir(qgetenv("ALLUSERSPROFILE"))); // sword dir for Windows only
+    cachedSharedSwordDir.reset(new QDir(qgetenv("ProgramData"))); // sword dir for Windows only
     if (!cachedSharedSwordDir->cd("Application Data")) {
-        qWarning() << "Cannot find ALLUSERSPROFILE\\Application Data";
+        qWarning() << "Cannot find %ProgramData%";
         return false;
     }
     if (!cachedSharedSwordDir->cd(SWORD_DIR)) {
         if (!cachedSharedSwordDir->mkdir(SWORD_DIR) || !cachedSharedSwordDir->cd(SWORD_DIR)) {
-            qWarning() << "Cannot find ALLUSERSPROFILE\\Application Data\\Sword";
+            qWarning() << "Cannot find %ProgramData%\\Sword";
             return false;
         }
     }
@@ -229,6 +232,12 @@ bool initDirectoryCache() {
             return false;
         }
     }
+#elif defined Q_OS_WIN32
+#define BUFSIZE 4096
+    wchar_t homeDir[BUFSIZE];
+    GetEnvironmentVariable(TEXT("APPDATA"), homeDir, BUFSIZE);
+    QString qHomeDir = QString::fromWCharArray(homeDir);
+    cachedUserHomeDir.reset(new QDir(qHomeDir));
 #else
     cachedUserHomeDir.reset(new QDir(qgetenv("HOME")));
 #endif
